==> Legcord-1.1.5.tar.gz: Legcord-1.1.5/src/shelter/rpc/index.ts <==
import { fetchApp, fetchAssetId, fetchExternalAsset } from "./asset.js";

const {
    flux: { dispatcher: FluxDispatcher },
} = shelter;

export function onLoad() {
    window.LegcordRPC.listen(
        async (msg: {
            activity: {
                assets: { large_image: string | null; small_image: string | null };
                application_id: number;
                name: string;
            };
        }) => {
            if (msg.activity?.assets?.large_image?.startsWith("https://")) {
                console.log(fetchExternalAsset(msg.activity.application_id, msg.activity.assets.large_image));
            } else {
                if (msg.activity?.assets?.large_image)
                    msg.activity.assets.large_image = await fetchAssetId(
                        msg.activity.application_id,
                        msg.activity.assets.large_image,
                    );
                if (msg.activity?.assets?.small_image)
                    msg.activity.assets.small_image = await fetchAssetId(
                        msg.activity.application_id,
                        msg.activity.assets.small_image,
                    );
            }
            if (msg.activity) {
                const appId = msg.activity.application_id;
                const app = await fetchApp(appId);
                if (!msg.activity.name) msg.activity.name = app.name;
                console.log("RPC activity update", msg.activity);
            }
            FluxDispatcher.dispatch({ type: "LOCAL_ACTIVITY_UPDATE", ...msg }); // set RPC status
        },
    );
}

==> Legcord-1.1.6.tar.gz: Legcord-1.1.6/src/shelter/rpc/index.ts <==
import { fetchApp, fetchAssetId, fetchExternalAsset } from "./asset.js";

const {
    flux: { dispatcher: FluxDispatcher },
} = shelter;

export function onLoad() {
    window.legcord.rpc.listen(
        async (msg: {
            activity: {
                assets: { large_image: string | null | undefined; small_image: string | null | undefined };
                application_id: number;
                name: string;
            };
        }) => {
            if (
                msg.activity?.assets?.large_image?.startsWith("https://") ??
                msg.activity?.assets?.small_image?.startsWith("https://")
            ) {
                if (typeof msg.activity.assets.large_image === "string") {
                    msg.activity.assets.large_image = await fetchExternalAsset(
                        msg.activity.application_id,
                        msg.activity.assets.large_image,
                    );
                }
                if (typeof msg.activity.assets.small_image === "string") {
                    msg.activity.assets.small_image = await fetchExternalAsset(
                        msg.activity.application_id,
                        msg.activity.assets.small_image,
                    );
                }
            } else {
                if (msg.activity?.assets?.large_image)
                    msg.activity.assets.large_image = await fetchAssetId(
                        msg.activity.application_id,
                        msg.activity.assets.large_image,
                    );
                if (msg.activity?.assets?.small_image)
                    msg.activity.assets.small_image = await fetchAssetId(
                        msg.activity.application_id,
                        msg.activity.assets.small_image,
                    );
            }
            if (msg.activity) {
                const appId = msg.activity.application_id;
                const app = await fetchApp(appId);
                if (!msg.activity.name) msg.activity.name = app.name;
                console.log("RPC activity update", msg.activity);
            }
            FluxDispatcher.dispatch({ type: "LOCAL_ACTIVITY_UPDATE", ...msg }); // set RPC status
        },
    );
}
